@@ -20,11 +20,11 @@
 
 use 5.014_001;
 
-package Term::CLI::Argument::Bool  0.04004 {
+package Term::CLI::Argument::Bool  0.04005 {
 
-use Modern::Perl;
+use Modern::Perl 1.20140107;
 
-use Types::Standard qw(
+use Types::Standard 1.000005 qw(
     ArrayRef
     Str
     Bool
@@ -32,8 +32,8 @@ use Types::Standard qw(
 
 use Term::CLI::L10N;
 
-use Moo;
-use namespace::clean;
+use Moo 1.006001;
+use namespace::clean 0.25;
 
 extends 'Term::CLI::Argument';
 
@@ -140,7 +140,7 @@ Term::CLI::Argument::Bool - class for "boolean" arguments in Term::CLI
 
 =head1 VERSION
 
-version 0.04004
+version 0.04005
 
 =head1 SYNOPSIS
 
