@@ -20,11 +20,11 @@
 
 use 5.014_001;
 
-package Term::CLI::Argument::Filename  0.04004 {
+package Term::CLI::Argument::Filename  0.04005 {
 
-use Modern::Perl;
-use Moo;
-use namespace::clean;
+use Modern::Perl 1.20140107;
+use Moo 1.006001;
+use namespace::clean 0.25;
 
 extends 'Term::CLI::Argument';
 
@@ -58,7 +58,7 @@ Term::CLI::Argument::Filename - class for file name arguments in Term::CLI
 
 =head1 VERSION
 
-version 0.04004
+version 0.04005
 
 =head1 SYNOPSIS
 
