@@ -20,13 +20,13 @@
 
 use 5.014_001;
 
-package Term::CLI::Argument::Number  0.04004 {
+package Term::CLI::Argument::Number  0.04005 {
 
-use Modern::Perl;
+use Modern::Perl 1.20140107;
 use Term::CLI::L10N;
 
-use Moo;
-use namespace::clean;
+use Moo 1.006001;
+use namespace::clean 0.25;
 
 extends 'Term::CLI::Argument';
 
@@ -84,7 +84,7 @@ Term::CLI::Argument::Number - base class for numerical arguments in Term::CLI
 
 =head1 VERSION
 
-version 0.04004
+version 0.04005
 
 =head1 SYNOPSIS
 
