@@ -20,14 +20,14 @@
 
 use 5.014_001;
 
-package Term::CLI::Argument::Number::Float  0.04004 {
+package Term::CLI::Argument::Number::Float  0.04005 {
 
-use Modern::Perl;
-use POSIX qw( );
-use Scalar::Util qw( looks_like_number );
+use Modern::Perl 1.20140107;
+use POSIX 1.38_03 qw( );
+use Scalar::Util 1.38 qw( looks_like_number );
 
-use Moo;
-use namespace::clean;
+use Moo 1.006001;
+use namespace::clean 0.25;
 
 extends 'Term::CLI::Argument::Number';
 
@@ -52,7 +52,7 @@ Term::CLI::Argument::Number::Float - class for floating point arguments in Term:
 
 =head1 VERSION
 
-version 0.04004
+version 0.04005
 
 =head1 SYNOPSIS
 
