@@ -20,11 +20,11 @@
 
 use 5.014_001;
 
-package Term::CLI::Argument::Number::Int  0.04004 {
+package Term::CLI::Argument::Number::Int  0.04005 {
 
-use Modern::Perl;
-use Moo;
-use namespace::clean;
+use Modern::Perl 1.20140107;
+use Moo 1.006001;
+use namespace::clean 0.25;
 
 extends 'Term::CLI::Argument::Number';
 
@@ -51,7 +51,7 @@ Term::CLI::Argument::Number::Int - class for integer arguments in Term::CLI
 
 =head1 VERSION
 
-version 0.04004
+version 0.04005
 
 =head1 SYNOPSIS
 
