@@ -20,14 +20,14 @@
 
 use 5.014_001;
 
-package Term::CLI::Command::Help  0.04004 {
+package Term::CLI::Command::Help  0.04005 {
 
-use Modern::Perl;
-use Pod::Text::Termcap;
-use List::Util qw( first );
-use File::Which;
-use Types::Standard qw( ArrayRef Str );
-use Getopt::Long qw( GetOptionsFromArray );
+use Modern::Perl 1.20140107;
+use Pod::Text::Termcap 2.08;
+use List::Util 1.38 qw( first );
+use File::Which 1.09;
+use Types::Standard 1.000005 qw( ArrayRef Str );
+use Getopt::Long 2.42 qw( GetOptionsFromArray );
 use Term::CLI::L10N;
 
 my @PAGERS = (
@@ -45,8 +45,8 @@ if (my $pager = first { defined which($_->[0]) } @PAGERS) {
     @PAGER = @$pager;
 }
 
-use Moo;
-use namespace::clean;
+use Moo 1.006001;
+use namespace::clean 0.25;
 
 extends 'Term::CLI::Command';
 
@@ -293,8 +293,6 @@ sub _execute_help {
     my $pager_fh;
     my $pager_cmd = $self->pager;
 
-    local( $::SIG{PIPE} ) = 'IGNORE'; # Temporarily avoid accidents.
-
     if (@$pager_cmd) {
         no warnings 'exec';
         if (!open $pager_fh, "|-", @{$pager_cmd}) {
@@ -302,18 +300,25 @@ sub _execute_help {
             $args{error} = loc("cannot run '[_1]': [_2]", $$pager_cmd[0], $!);
             return %args;
         }
-    }
-    elsif (!open $pager_fh, '>&', \*STDOUT) {
-        $args{status} = -1;
-        $args{error} = "dup(STDOUT): $!";
-        return %args;
-    }
 
-    print $pager_fh $args{text};
+        local( $::SIG{PIPE} ) = 'IGNORE'; # Temporarily avoid accidents.
+        print $pager_fh $args{text};
 
-    if (!$pager_fh->close) {
+        $pager_fh->close;
         $args{status} = $?;
-        $args{error} = $!;
+        $args{error} = $! if $args{status} != 0;
+    }
+    else { 
+        if (!open $pager_fh, '>&', \*STDOUT) {
+            $args{status} = -1;
+            $args{error} = "dup(STDOUT): $!";
+            return %args;
+        }
+        print $pager_fh $args{text};
+        if (!$pager_fh->close) {
+            $args{status} = -1;
+            $args{error} = $!;
+        }
     }
     return %args;
 }
@@ -332,7 +337,7 @@ Term::CLI::Command::Help - A generic 'help' command for Term::CLI
 
 =head1 VERSION
 
-version 0.04004
+version 0.04005
 
 =head1 SYNOPSIS
 
