@@ -20,15 +20,15 @@
 
 use 5.014_001;
 
-package Term::CLI::Element  0.04004 {
+package Term::CLI::Element  0.04005 {
 
-use Modern::Perl;
+use Modern::Perl 1.20140107;
 use Term::CLI::ReadLine;
 
-use Types::Standard qw( Str );
+use Types::Standard 1.000005 qw( Str );
 
-use Moo;
-use namespace::clean;
+use Moo 1.006001;
+use namespace::clean 0.25;
 
 extends 'Term::CLI::Base';
 
@@ -48,7 +48,7 @@ Term::CLI::Element - generic parent class for elements in Term::CLI
 
 =head1 VERSION
 
-version 0.04004
+version 0.04005
 
 =head1 SYNOPSIS
 
