@@ -18,11 +18,11 @@
 
 use 5.014_001;
 
-package Term::CLI::L10N  0.04004 {
+package Term::CLI::L10N  0.04005 {
 
-use Modern::Perl;
+use Modern::Perl 1.20140107;
 
-use parent qw( Locale::Maketext Exporter );
+use parent 0.228 qw( Locale::Maketext Exporter );
 
 BEGIN {
     our @EXPORT_OK   = qw( __ loc );
@@ -73,7 +73,7 @@ Term::CLI::L10N - localizations for Term::CLI
 
 =head1 VERSION
 
-version 0.04004
+version 0.04005
 
 =head1 SYNOPSIS
 
