@@ -19,20 +19,20 @@ use 5.014_001;
 
 package Term::CLI::L10N::nl;
 
-our $VERSION = 0.04004;
+our $VERSION = 0.04005;
 
-use Modern::Perl;
+use Modern::Perl 1.20140107;
 
-use parent qw( Term::CLI::L10N );
+use parent 0.228 qw( Term::CLI::L10N );
 
-use Locale::Maketext::Lexicon::Gettext;
+use Locale::Maketext::Lexicon::Gettext 1.00;
 
 our %Lexicon = %{ Locale::Maketext::Lexicon::Gettext->parse(<DATA>) };
 close DATA;
 
 # $str = $lh->singularize($num, $plural);
 # $str = $lh->singularise($num, $plural);
-use subs qw( singularise );
+use subs 1.02 qw( singularise );
 *singularise = \&singularize;
 
 sub singularize {
@@ -289,7 +289,7 @@ Term::CLI::L10N::nl - Dutch localizations for Term::CLI
 
 =head1 VERSION
 
-version 0.04004
+version 0.04005
 
 =head1 SYNOPSIS
 
