@@ -20,12 +20,12 @@
 
 use 5.014_001;
 
-package Term::CLI::Role::CommandSet  0.04004 {
+package Term::CLI::Role::CommandSet  0.04005 {
 
-use Modern::Perl;
+use Modern::Perl 1.20140107;
 use Term::CLI::L10N;
 
-use Types::Standard qw(
+use Types::Standard 1.000005 qw(
     ArrayRef
     CodeRef
     InstanceOf
@@ -33,8 +33,8 @@ use Types::Standard qw(
     Maybe
 );
 
-use Moo::Role;
-use namespace::clean;
+use Moo::Role 1.006001;
+use namespace::clean 0.25;
 
 has parent => (
     is       => 'rwp',
@@ -174,7 +174,7 @@ Term::CLI::Role::CommandSet - Role for (sub-)commands in Term::CLI
 
 =head1 VERSION
 
-version 0.04004
+version 0.04005
 
 =head1 SYNOPSIS
 
