@@ -20,17 +20,17 @@
 
 use 5.014_001;
 
-package Term::CLI::Role::HelpText  0.04004 {
+package Term::CLI::Role::HelpText  0.04005 {
 
-use Modern::Perl;
+use Modern::Perl 1.20140107;
 
-use Types::Standard qw(
+use Types::Standard 1.000005 qw(
     Maybe
     Str
 );
 
-use Moo::Role;
-use namespace::clean;
+use Moo::Role 1.006001;
+use namespace::clean 0.25;
 
 requires 'options';
 requires 'has_commands';
@@ -204,7 +204,7 @@ Term::CLI::Role::HelpText - Role for generating help text in Term::CLI
 
 =head1 VERSION
 
-version 0.04004
+version 0.04005
 
 =head1 SYNOPSIS
 
